@@ -240,7 +240,7 @@ class TestGenerateRuns:
         )
         assert len(runs) == 3
         assert runs[0].endswith(
-            "--scenario time_resampling --save_netcdf out_1_time_resampling.nc"
+            "--scenario time_resampling --save_netcdf out_1_time_resampling.nc --save_plots plots_1_time_resampling.html"
         )
 
     @python36_or_higher
@@ -248,14 +248,19 @@ class TestGenerateRuns:
         runs = generate_runs(_MODEL_NATIONAL, scenarios=None)
         assert len(runs) == 2
         assert runs[0].endswith(
-            "--scenario cold_fusion_with_production_share --save_netcdf out_1_cold_fusion_with_production_share.nc"
+            "--scenario cold_fusion_with_production_share --save_netcdf out_1_cold_fusion_with_production_share.nc --save_plots plots_1_cold_fusion_with_production_share.html"
         )
 
     @python36_or_higher
     def test_generate_runs_scenarios_none_with_overrides(self):
-        runs = generate_runs(_MODEL_URBAN, scenarios=None,)
+        runs = generate_runs(
+            _MODEL_URBAN,
+            scenarios=None,
+        )
         assert len(runs) == 4
-        assert runs[0].endswith("--scenario milp --save_netcdf out_1_milp.nc")
+        assert runs[0].endswith(
+            "--scenario milp --save_netcdf out_1_milp.nc --save_plots plots_1_milp.html"
+        )
 
 
 class TestPandasExport:
